==> mongodb-7.0.18.gh.tar.gz: mongo-r7.0.18/src/mongo/transport/grpc/mock_client_stream.cpp <==
/**
 *    Copyright (C) 2023-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/transport/grpc/mock_client_stream.h"

#include "mongo/db/service_context.h"
#include "mongo/transport/grpc/mock_util.h"

namespace mongo::transport::grpc {

MockClientStream::MockClientStream(HostAndPort hostAndPort,
                                   Milliseconds timeout,
                                   Future<MetadataContainer>&& initialMetadataFuture,
                                   BidirectionalPipe::End&& pipe)
    : _deadline{getGlobalServiceContext()->getFastClockSource()->now() + timeout},
      _serverInitialMetadata{std::move(initialMetadataFuture)},
      _pipe{std::move(pipe)} {}

boost::optional<SharedBuffer> MockClientStream::read() {
    return runWithDeadline<boost::optional<SharedBuffer>>(
        _deadline, [&](Interruptible* i) { return _pipe.read(i); });
}

bool MockClientStream::write(ConstSharedBuffer msg) {
    return runWithDeadline<bool>(_deadline, [&](Interruptible* i) { return _pipe.write(msg, i); });
}

}  // namespace mongo::transport::grpc

==> mongodb-7.0.23.gh.tar.gz: mongo-r7.0.23/src/mongo/transport/grpc/mock_client_stream.cpp <==
/**
 *    Copyright (C) 2023-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/transport/grpc/mock_client_stream.h"

#include "mongo/db/service_context.h"
#include "mongo/transport/grpc/mock_util.h"

namespace mongo::transport::grpc {

MockClientStream::MockClientStream(HostAndPort hostAndPort,
                                   Date_t deadline,
                                   Future<MetadataContainer>&& initialMetadataFuture,
                                   BidirectionalPipe::End&& pipe)
    : _deadline{deadline},
      _serverInitialMetadata{std::move(initialMetadataFuture)},
      _pipe{std::move(pipe)} {}

boost::optional<SharedBuffer> MockClientStream::read() {
    return runWithDeadline<boost::optional<SharedBuffer>>(
        _deadline, [&](Interruptible* i) { return _pipe.read(i); });
}

bool MockClientStream::write(ConstSharedBuffer msg) {
    return runWithDeadline<bool>(_deadline, [&](Interruptible* i) { return _pipe.write(msg, i); });
}

}  // namespace mongo::transport::grpc
